# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ClusterPrivateNetworkArgs',
    'ClusterPrivateNetworkArgsDict',
    'ClusterPublicNetworkArgs',
    'ClusterPublicNetworkArgsDict',
]

MYPY = False

if not MYPY:
    class ClusterPrivateNetworkArgsDict(TypedDict):
        pn_id: pulumi.Input[_builtins.str]
        """
        The private network ID (same as input).
        """
        dns_records: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of DNS records for the private endpoint.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the private endpoint.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        TCP port number.
        """
elif False:
    ClusterPrivateNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ClusterPrivateNetworkArgs:
    def __init__(__self__, *,
                 pn_id: pulumi.Input[_builtins.str],
                 dns_records: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] pn_id: The private network ID (same as input).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_records: List of DNS records for the private endpoint.
        :param pulumi.Input[_builtins.str] id: The ID of the private endpoint.
        :param pulumi.Input[_builtins.int] port: TCP port number.
        """
        pulumi.set(__self__, "pn_id", pn_id)
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="pnId")
    def pn_id(self) -> pulumi.Input[_builtins.str]:
        """
        The private network ID (same as input).
        """
        return pulumi.get(self, "pn_id")

    @pn_id.setter
    def pn_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pn_id", value)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of DNS records for the private endpoint.
        """
        return pulumi.get(self, "dns_records")

    @dns_records.setter
    def dns_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_records", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the private endpoint.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port number.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class ClusterPublicNetworkArgsDict(TypedDict):
        dns_records: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of DNS records for the private endpoint.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the private endpoint.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        TCP port number.
        """
elif False:
    ClusterPublicNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ClusterPublicNetworkArgs:
    def __init__(__self__, *,
                 dns_records: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_records: List of DNS records for the private endpoint.
        :param pulumi.Input[_builtins.str] id: The ID of the private endpoint.
        :param pulumi.Input[_builtins.int] port: TCP port number.
        """
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of DNS records for the private endpoint.
        """
        return pulumi.get(self, "dns_records")

    @dns_records.setter
    def dns_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_records", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the private endpoint.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port number.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['EdgeServicesHeadStageArgs', 'EdgeServicesHeadStage']

@pulumi.input_type
class EdgeServicesHeadStageArgs:
    def __init__(__self__, *,
                 pipeline_id: pulumi.Input[_builtins.str],
                 head_stage_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EdgeServicesHeadStage resource.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] head_stage_id: The ID of head stage of the pipeline.
        """
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if head_stage_id is not None:
            pulumi.set(__self__, "head_stage_id", head_stage_id)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="headStageId")
    def head_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of head stage of the pipeline.
        """
        return pulumi.get(self, "head_stage_id")

    @head_stage_id.setter
    def head_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "head_stage_id", value)


@pulumi.input_type
class _EdgeServicesHeadStageState:
    def __init__(__self__, *,
                 head_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EdgeServicesHeadStage resources.
        :param pulumi.Input[_builtins.str] head_stage_id: The ID of head stage of the pipeline.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        """
        if head_stage_id is not None:
            pulumi.set(__self__, "head_stage_id", head_stage_id)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)

    @_builtins.property
    @pulumi.getter(name="headStageId")
    def head_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of head stage of the pipeline.
        """
        return pulumi.get(self, "head_stage_id")

    @head_stage_id.setter
    def head_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "head_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_id", value)


warnings.warn("""scaleway.index/edgeservicesheadstage.EdgeServicesHeadStage has been deprecated in favor of scaleway.edgeservices/headstage.HeadStage""", DeprecationWarning)


@pulumi.type_token("scaleway:index/edgeServicesHeadStage:EdgeServicesHeadStage")
class EdgeServicesHeadStage(pulumi.CustomResource):
    warnings.warn("""scaleway.index/edgeservicesheadstage.EdgeServicesHeadStage has been deprecated in favor of scaleway.edgeservices/headstage.HeadStage""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 head_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Sets the Scaleway Edge Services head stage of your pipeline.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.Pipeline("main",
            name="my-edge_services-pipeline",
            description="pipeline description")
        main_dns_stage = scaleway.edgeservices.DnsStage("main",
            pipeline_id=main.id,
            tls_stage_id=main_scaleway_edge_services_tls_stage["id"],
            fqdns=["subdomain.example.com"])
        main_head_stage = scaleway.edgeservices.HeadStage("main",
            pipeline_id=main.id,
            head_stage_id=main_dns_stage.id)
        ```

        ## Import

        Head stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesHeadStage:EdgeServicesHeadStage main 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] head_stage_id: The ID of head stage of the pipeline.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EdgeServicesHeadStageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sets the Scaleway Edge Services head stage of your pipeline.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.Pipeline("main",
            name="my-edge_services-pipeline",
            description="pipeline description")
        main_dns_stage = scaleway.edgeservices.DnsStage("main",
            pipeline_id=main.id,
            tls_stage_id=main_scaleway_edge_services_tls_stage["id"],
            fqdns=["subdomain.example.com"])
        main_head_stage = scaleway.edgeservices.HeadStage("main",
            pipeline_id=main.id,
            head_stage_id=main_dns_stage.id)
        ```

        ## Import

        Head stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesHeadStage:EdgeServicesHeadStage main 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param EdgeServicesHeadStageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EdgeServicesHeadStageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 head_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""EdgeServicesHeadStage is deprecated: scaleway.index/edgeservicesheadstage.EdgeServicesHeadStage has been deprecated in favor of scaleway.edgeservices/headstage.HeadStage""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EdgeServicesHeadStageArgs.__new__(EdgeServicesHeadStageArgs)

            __props__.__dict__["head_stage_id"] = head_stage_id
            if pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_id'")
            __props__.__dict__["pipeline_id"] = pipeline_id
        super(EdgeServicesHeadStage, __self__).__init__(
            'scaleway:index/edgeServicesHeadStage:EdgeServicesHeadStage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            head_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'EdgeServicesHeadStage':
        """
        Get an existing EdgeServicesHeadStage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] head_stage_id: The ID of head stage of the pipeline.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EdgeServicesHeadStageState.__new__(_EdgeServicesHeadStageState)

        __props__.__dict__["head_stage_id"] = head_stage_id
        __props__.__dict__["pipeline_id"] = pipeline_id
        return EdgeServicesHeadStage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="headStageId")
    def head_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of head stage of the pipeline.
        """
        return pulumi.get(self, "head_stage_id")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerResult',
    'AwaitableGetServerResult',
    'get_server',
    'get_server_output',
]

@pulumi.output_type
class GetServerResult:
    """
    A collection of values returned by getServer.
    """
    def __init__(__self__, cloud_init=None, description=None, domain=None, hostname=None, id=None, install_config_afterward=None, ips=None, ipv4s=None, ipv6s=None, name=None, offer=None, offer_id=None, offer_name=None, options=None, organization_id=None, os=None, os_name=None, partitioning=None, password=None, password_wo=None, password_wo_version=None, private_ips=None, private_networks=None, project_id=None, protected=None, reinstall_on_config_changes=None, server_id=None, service_password=None, service_password_wo=None, service_password_wo_version=None, service_user=None, ssh_key_ids=None, tags=None, user=None, zone=None):
        if cloud_init and not isinstance(cloud_init, str):
            raise TypeError("Expected argument 'cloud_init' to be a str")
        pulumi.set(__self__, "cloud_init", cloud_init)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if install_config_afterward and not isinstance(install_config_afterward, bool):
            raise TypeError("Expected argument 'install_config_afterward' to be a bool")
        pulumi.set(__self__, "install_config_afterward", install_config_afterward)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if ipv4s and not isinstance(ipv4s, list):
            raise TypeError("Expected argument 'ipv4s' to be a list")
        pulumi.set(__self__, "ipv4s", ipv4s)
        if ipv6s and not isinstance(ipv6s, list):
            raise TypeError("Expected argument 'ipv6s' to be a list")
        pulumi.set(__self__, "ipv6s", ipv6s)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if offer and not isinstance(offer, str):
            raise TypeError("Expected argument 'offer' to be a str")
        pulumi.set(__self__, "offer", offer)
        if offer_id and not isinstance(offer_id, str):
            raise TypeError("Expected argument 'offer_id' to be a str")
        pulumi.set(__self__, "offer_id", offer_id)
        if offer_name and not isinstance(offer_name, str):
            raise TypeError("Expected argument 'offer_name' to be a str")
        pulumi.set(__self__, "offer_name", offer_name)
        if options and not isinstance(options, list):
            raise TypeError("Expected argument 'options' to be a list")
        pulumi.set(__self__, "options", options)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if os and not isinstance(os, str):
            raise TypeError("Expected argument 'os' to be a str")
        pulumi.set(__self__, "os", os)
        if os_name and not isinstance(os_name, str):
            raise TypeError("Expected argument 'os_name' to be a str")
        pulumi.set(__self__, "os_name", os_name)
        if partitioning and not isinstance(partitioning, str):
            raise TypeError("Expected argument 'partitioning' to be a str")
        pulumi.set(__self__, "partitioning", partitioning)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if password_wo and not isinstance(password_wo, str):
            raise TypeError("Expected argument 'password_wo' to be a str")
        pulumi.set(__self__, "password_wo", password_wo)
        if password_wo_version and not isinstance(password_wo_version, int):
            raise TypeError("Expected argument 'password_wo_version' to be a int")
        pulumi.set(__self__, "password_wo_version", password_wo_version)
        if private_ips and not isinstance(private_ips, list):
            raise TypeError("Expected argument 'private_ips' to be a list")
        pulumi.set(__self__, "private_ips", private_ips)
        if private_networks and not isinstance(private_networks, list):
            raise TypeError("Expected argument 'private_networks' to be a list")
        pulumi.set(__self__, "private_networks", private_networks)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if protected and not isinstance(protected, bool):
            raise TypeError("Expected argument 'protected' to be a bool")
        pulumi.set(__self__, "protected", protected)
        if reinstall_on_config_changes and not isinstance(reinstall_on_config_changes, bool):
            raise TypeError("Expected argument 'reinstall_on_config_changes' to be a bool")
        pulumi.set(__self__, "reinstall_on_config_changes", reinstall_on_config_changes)
        if server_id and not isinstance(server_id, str):
            raise TypeError("Expected argument 'server_id' to be a str")
        pulumi.set(__self__, "server_id", server_id)
        if service_password and not isinstance(service_password, str):
            raise TypeError("Expected argument 'service_password' to be a str")
        pulumi.set(__self__, "service_password", service_password)
        if service_password_wo and not isinstance(service_password_wo, str):
            raise TypeError("Expected argument 'service_password_wo' to be a str")
        pulumi.set(__self__, "service_password_wo", service_password_wo)
        if service_password_wo_version and not isinstance(service_password_wo_version, int):
            raise TypeError("Expected argument 'service_password_wo_version' to be a int")
        pulumi.set(__self__, "service_password_wo_version", service_password_wo_version)
        if service_user and not isinstance(service_user, str):
            raise TypeError("Expected argument 'service_user' to be a str")
        pulumi.set(__self__, "service_user", service_user)
        if ssh_key_ids and not isinstance(ssh_key_ids, list):
            raise TypeError("Expected argument 'ssh_key_ids' to be a list")
        pulumi.set(__self__, "ssh_key_ids", ssh_key_ids)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if user and not isinstance(user, str):
            raise TypeError("Expected argument 'user' to be a str")
        pulumi.set(__self__, "user", user)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="cloudInit")
    def cloud_init(self) -> _builtins.str:
        return pulumi.get(self, "cloud_init")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def domain(self) -> _builtins.str:
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> _builtins.str:
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="installConfigAfterward")
    def install_config_afterward(self) -> _builtins.bool:
        return pulumi.get(self, "install_config_afterward")

    @_builtins.property
    @pulumi.getter
    def ips(self) -> Sequence['outputs.GetServerIpResult']:
        return pulumi.get(self, "ips")

    @_builtins.property
    @pulumi.getter
    def ipv4s(self) -> Sequence['outputs.GetServerIpv4Result']:
        return pulumi.get(self, "ipv4s")

    @_builtins.property
    @pulumi.getter
    def ipv6s(self) -> Sequence['outputs.GetServerIpv6Result']:
        return pulumi.get(self, "ipv6s")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def offer(self) -> _builtins.str:
        return pulumi.get(self, "offer")

    @_builtins.property
    @pulumi.getter(name="offerId")
    def offer_id(self) -> _builtins.str:
        return pulumi.get(self, "offer_id")

    @_builtins.property
    @pulumi.getter(name="offerName")
    def offer_name(self) -> _builtins.str:
        return pulumi.get(self, "offer_name")

    @_builtins.property
    @pulumi.getter
    def options(self) -> Sequence['outputs.GetServerOptionResult']:
        return pulumi.get(self, "options")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter
    def os(self) -> _builtins.str:
        return pulumi.get(self, "os")

    @_builtins.property
    @pulumi.getter(name="osName")
    def os_name(self) -> _builtins.str:
        return pulumi.get(self, "os_name")

    @_builtins.property
    @pulumi.getter
    def partitioning(self) -> _builtins.str:
        return pulumi.get(self, "partitioning")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="passwordWo")
    def password_wo(self) -> _builtins.str:
        return pulumi.get(self, "password_wo")

    @_builtins.property
    @pulumi.getter(name="passwordWoVersion")
    def password_wo_version(self) -> _builtins.int:
        return pulumi.get(self, "password_wo_version")

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Sequence['outputs.GetServerPrivateIpResult']:
        return pulumi.get(self, "private_ips")

    @_builtins.property
    @pulumi.getter(name="privateNetworks")
    def private_networks(self) -> Sequence['outputs.GetServerPrivateNetworkResult']:
        return pulumi.get(self, "private_networks")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def protected(self) -> _builtins.bool:
        return pulumi.get(self, "protected")

    @_builtins.property
    @pulumi.getter(name="reinstallOnConfigChanges")
    def reinstall_on_config_changes(self) -> _builtins.bool:
        return pulumi.get(self, "reinstall_on_config_changes")

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "server_id")

    @_builtins.property
    @pulumi.getter(name="servicePassword")
    def service_password(self) -> _builtins.str:
        return pulumi.get(self, "service_password")

    @_builtins.property
    @pulumi.getter(name="servicePasswordWo")
    def service_password_wo(self) -> _builtins.str:
        return pulumi.get(self, "service_password_wo")

    @_builtins.property
    @pulumi.getter(name="servicePasswordWoVersion")
    def service_password_wo_version(self) -> _builtins.int:
        return pulumi.get(self, "service_password_wo_version")

    @_builtins.property
    @pulumi.getter(name="serviceUser")
    def service_user(self) -> _builtins.str:
        return pulumi.get(self, "service_user")

    @_builtins.property
    @pulumi.getter(name="sshKeyIds")
    def ssh_key_ids(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "ssh_key_ids")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def user(self) -> _builtins.str:
        return pulumi.get(self, "user")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "zone")


class AwaitableGetServerResult(GetServerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerResult(
            cloud_init=self.cloud_init,
            description=self.description,
            domain=self.domain,
            hostname=self.hostname,
            id=self.id,
            install_config_afterward=self.install_config_afterward,
            ips=self.ips,
            ipv4s=self.ipv4s,
            ipv6s=self.ipv6s,
            name=self.name,
            offer=self.offer,
            offer_id=self.offer_id,
            offer_name=self.offer_name,
            options=self.options,
            organization_id=self.organization_id,
            os=self.os,
            os_name=self.os_name,
            partitioning=self.partitioning,
            password=self.password,
            password_wo=self.password_wo,
            password_wo_version=self.password_wo_version,
            private_ips=self.private_ips,
            private_networks=self.private_networks,
            project_id=self.project_id,
            protected=self.protected,
            reinstall_on_config_changes=self.reinstall_on_config_changes,
            server_id=self.server_id,
            service_password=self.service_password,
            service_password_wo=self.service_password_wo,
            service_password_wo_version=self.service_password_wo_version,
            service_user=self.service_user,
            ssh_key_ids=self.ssh_key_ids,
            tags=self.tags,
            user=self.user,
            zone=self.zone)


def get_server(name: Optional[_builtins.str] = None,
               project_id: Optional[_builtins.str] = None,
               server_id: Optional[_builtins.str] = None,
               zone: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerResult:
    """
    Gets information about a baremetal server.
    For more information, see the [API documentation](https://developers.scaleway.com/en/products/baremetal/api).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by server name
    by_name = scaleway.elasticmetal.get_server(name="foobar",
        zone="fr-par-2")
    # Get info by server id
    by_id = scaleway.elasticmetal.get_server(server_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str name: The server name. Only one of `name` and `server_id` should be specified.
    :param _builtins.str project_id: The ID of the project the baremetal server is associated with.
    :param _builtins.str zone: `zone`) The zone in which the server exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['serverId'] = server_id
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:elasticmetal/getServer:getServer', __args__, opts=opts, typ=GetServerResult).value

    return AwaitableGetServerResult(
        cloud_init=pulumi.get(__ret__, 'cloud_init'),
        description=pulumi.get(__ret__, 'description'),
        domain=pulumi.get(__ret__, 'domain'),
        hostname=pulumi.get(__ret__, 'hostname'),
        id=pulumi.get(__ret__, 'id'),
        install_config_afterward=pulumi.get(__ret__, 'install_config_afterward'),
        ips=pulumi.get(__ret__, 'ips'),
        ipv4s=pulumi.get(__ret__, 'ipv4s'),
        ipv6s=pulumi.get(__ret__, 'ipv6s'),
        name=pulumi.get(__ret__, 'name'),
        offer=pulumi.get(__ret__, 'offer'),
        offer_id=pulumi.get(__ret__, 'offer_id'),
        offer_name=pulumi.get(__ret__, 'offer_name'),
        options=pulumi.get(__ret__, 'options'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        os=pulumi.get(__ret__, 'os'),
        os_name=pulumi.get(__ret__, 'os_name'),
        partitioning=pulumi.get(__ret__, 'partitioning'),
        password=pulumi.get(__ret__, 'password'),
        password_wo=pulumi.get(__ret__, 'password_wo'),
        password_wo_version=pulumi.get(__ret__, 'password_wo_version'),
        private_ips=pulumi.get(__ret__, 'private_ips'),
        private_networks=pulumi.get(__ret__, 'private_networks'),
        project_id=pulumi.get(__ret__, 'project_id'),
        protected=pulumi.get(__ret__, 'protected'),
        reinstall_on_config_changes=pulumi.get(__ret__, 'reinstall_on_config_changes'),
        server_id=pulumi.get(__ret__, 'server_id'),
        service_password=pulumi.get(__ret__, 'service_password'),
        service_password_wo=pulumi.get(__ret__, 'service_password_wo'),
        service_password_wo_version=pulumi.get(__ret__, 'service_password_wo_version'),
        service_user=pulumi.get(__ret__, 'service_user'),
        ssh_key_ids=pulumi.get(__ret__, 'ssh_key_ids'),
        tags=pulumi.get(__ret__, 'tags'),
        user=pulumi.get(__ret__, 'user'),
        zone=pulumi.get(__ret__, 'zone'))
def get_server_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      server_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      zone: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerResult]:
    """
    Gets information about a baremetal server.
    For more information, see the [API documentation](https://developers.scaleway.com/en/products/baremetal/api).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by server name
    by_name = scaleway.elasticmetal.get_server(name="foobar",
        zone="fr-par-2")
    # Get info by server id
    by_id = scaleway.elasticmetal.get_server(server_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str name: The server name. Only one of `name` and `server_id` should be specified.
    :param _builtins.str project_id: The ID of the project the baremetal server is associated with.
    :param _builtins.str zone: `zone`) The zone in which the server exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['serverId'] = server_id
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:elasticmetal/getServer:getServer', __args__, opts=opts, typ=GetServerResult)
    return __ret__.apply(lambda __response__: GetServerResult(
        cloud_init=pulumi.get(__response__, 'cloud_init'),
        description=pulumi.get(__response__, 'description'),
        domain=pulumi.get(__response__, 'domain'),
        hostname=pulumi.get(__response__, 'hostname'),
        id=pulumi.get(__response__, 'id'),
        install_config_afterward=pulumi.get(__response__, 'install_config_afterward'),
        ips=pulumi.get(__response__, 'ips'),
        ipv4s=pulumi.get(__response__, 'ipv4s'),
        ipv6s=pulumi.get(__response__, 'ipv6s'),
        name=pulumi.get(__response__, 'name'),
        offer=pulumi.get(__response__, 'offer'),
        offer_id=pulumi.get(__response__, 'offer_id'),
        offer_name=pulumi.get(__response__, 'offer_name'),
        options=pulumi.get(__response__, 'options'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        os=pulumi.get(__response__, 'os'),
        os_name=pulumi.get(__response__, 'os_name'),
        partitioning=pulumi.get(__response__, 'partitioning'),
        password=pulumi.get(__response__, 'password'),
        password_wo=pulumi.get(__response__, 'password_wo'),
        password_wo_version=pulumi.get(__response__, 'password_wo_version'),
        private_ips=pulumi.get(__response__, 'private_ips'),
        private_networks=pulumi.get(__response__, 'private_networks'),
        project_id=pulumi.get(__response__, 'project_id'),
        protected=pulumi.get(__response__, 'protected'),
        reinstall_on_config_changes=pulumi.get(__response__, 'reinstall_on_config_changes'),
        server_id=pulumi.get(__response__, 'server_id'),
        service_password=pulumi.get(__response__, 'service_password'),
        service_password_wo=pulumi.get(__response__, 'service_password_wo'),
        service_password_wo_version=pulumi.get(__response__, 'service_password_wo_version'),
        service_user=pulumi.get(__response__, 'service_user'),
        ssh_key_ids=pulumi.get(__response__, 'ssh_key_ids'),
        tags=pulumi.get(__response__, 'tags'),
        user=pulumi.get(__response__, 'user'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, email=None, id=None, organization_id=None, tags=None, user_id=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        """
        The tags associated with the user.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "user_id")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            email=self.email,
            id=self.id,
            organization_id=self.organization_id,
            tags=self.tags,
            user_id=self.user_id)


def get_user(email: Optional[_builtins.str] = None,
             organization_id: Optional[_builtins.str] = None,
             tags: Optional[Sequence[_builtins.str]] = None,
             user_id: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Use this data source to get information on an existing IAM user based on its ID or email address.
    For more information refer to the [IAM API documentation](https://developers.scaleway.com/en/products/iam/api/v1alpha1/#users-06bdcf).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by user id
    find_by_id = scaleway.iam.get_user(user_id="11111111-1111-1111-1111-111111111111")
    # Get info by email address
    find_by_email = scaleway.iam.get_user(email="foo@bar.com")
    ```


    :param _builtins.str email: The email address of the IAM user.
    :param _builtins.str organization_id: `organization_id`) The ID of the
           organization the user is associated with.
    :param Sequence[_builtins.str] tags: The tags associated with the user.
    :param _builtins.str user_id: The ID of the IAM user.
           
           > **Note** You must specify at least one: `email` and/or `user_id`.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['organizationId'] = organization_id
    __args__['tags'] = tags
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:iam/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        tags=pulumi.get(__ret__, 'tags'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_user_output(email: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    organization_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                    user_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Use this data source to get information on an existing IAM user based on its ID or email address.
    For more information refer to the [IAM API documentation](https://developers.scaleway.com/en/products/iam/api/v1alpha1/#users-06bdcf).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by user id
    find_by_id = scaleway.iam.get_user(user_id="11111111-1111-1111-1111-111111111111")
    # Get info by email address
    find_by_email = scaleway.iam.get_user(email="foo@bar.com")
    ```


    :param _builtins.str email: The email address of the IAM user.
    :param _builtins.str organization_id: `organization_id`) The ID of the
           organization the user is associated with.
    :param Sequence[_builtins.str] tags: The tags associated with the user.
    :param _builtins.str user_id: The ID of the IAM user.
           
           > **Note** You must specify at least one: `email` and/or `user_id`.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['organizationId'] = organization_id
    __args__['tags'] = tags
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:iam/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        tags=pulumi.get(__response__, 'tags'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstancePrivateIpArgs',
    'InstancePrivateIpArgsDict',
    'InstancePrivateNetworkArgs',
    'InstancePrivateNetworkArgsDict',
    'InstancePublicNetworkArgs',
    'InstancePublicNetworkArgsDict',
    'UserRoleArgs',
    'UserRoleArgsDict',
]

MYPY = False

if not MYPY:
    class InstancePrivateIpArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The private IPv4 address.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint.
        """
elif False:
    InstancePrivateIpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstancePrivateIpArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The private IPv4 address.
        :param pulumi.Input[_builtins.str] id: The ID of the endpoint.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private IPv4 address.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class InstancePrivateNetworkArgsDict(TypedDict):
        pn_id: pulumi.Input[_builtins.str]
        """
        The ID of the Private Network.
        """
        dns_records: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of DNS records for your endpoint.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint.
        """
        ips: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of IP addresses for your endpoint.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        TCP port of the endpoint.
        """
elif False:
    InstancePrivateNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstancePrivateNetworkArgs:
    def __init__(__self__, *,
                 pn_id: pulumi.Input[_builtins.str],
                 dns_records: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 ips: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] pn_id: The ID of the Private Network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_records: List of DNS records for your endpoint.
        :param pulumi.Input[_builtins.str] id: The ID of the endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ips: List of IP addresses for your endpoint.
        :param pulumi.Input[_builtins.int] port: TCP port of the endpoint.
        """
        pulumi.set(__self__, "pn_id", pn_id)
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if ips is not None:
            pulumi.set(__self__, "ips", ips)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="pnId")
    def pn_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Private Network.
        """
        return pulumi.get(self, "pn_id")

    @pn_id.setter
    def pn_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pn_id", value)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of DNS records for your endpoint.
        """
        return pulumi.get(self, "dns_records")

    @dns_records.setter
    def dns_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_records", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of IP addresses for your endpoint.
        """
        return pulumi.get(self, "ips")

    @ips.setter
    def ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ips", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port of the endpoint.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class InstancePublicNetworkArgsDict(TypedDict):
        dns_record: NotRequired[pulumi.Input[_builtins.str]]
        """
        The DNS record of your endpoint
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the endpoint.
        """
        port: NotRequired[pulumi.Input[_builtins.int]]
        """
        TCP port of the endpoint.
        """
elif False:
    InstancePublicNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstancePublicNetworkArgs:
    def __init__(__self__, *,
                 dns_record: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] dns_record: The DNS record of your endpoint
        :param pulumi.Input[_builtins.str] id: The ID of the endpoint.
        :param pulumi.Input[_builtins.int] port: TCP port of the endpoint.
        """
        if dns_record is not None:
            pulumi.set(__self__, "dns_record", dns_record)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="dnsRecord")
    def dns_record(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The DNS record of your endpoint
        """
        return pulumi.get(self, "dns_record")

    @dns_record.setter
    def dns_record(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_record", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port of the endpoint.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


if not MYPY:
    class UserRoleArgsDict(TypedDict):
        role: pulumi.Input[_builtins.str]
        """
        The role name. Valid values are `read`, `read_write`, `db_admin`, `sync`.
        """
        any_database: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Apply the role to all databases. Cannot be used with `database_name`.
        """
        database_name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The database name for the role. Cannot be used with `any_database`.
        """
elif False:
    UserRoleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserRoleArgs:
    def __init__(__self__, *,
                 role: pulumi.Input[_builtins.str],
                 any_database: Optional[pulumi.Input[_builtins.bool]] = None,
                 database_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] role: The role name. Valid values are `read`, `read_write`, `db_admin`, `sync`.
        :param pulumi.Input[_builtins.bool] any_database: Apply the role to all databases. Cannot be used with `database_name`.
        :param pulumi.Input[_builtins.str] database_name: The database name for the role. Cannot be used with `any_database`.
        """
        pulumi.set(__self__, "role", role)
        if any_database is not None:
            pulumi.set(__self__, "any_database", any_database)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Input[_builtins.str]:
        """
        The role name. Valid values are `read`, `read_write`, `db_admin`, `sync`.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="anyDatabase")
    def any_database(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Apply the role to all databases. Cannot be used with `database_name`.
        """
        return pulumi.get(self, "any_database")

    @any_database.setter
    def any_database(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "any_database", value)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The database name for the role. Cannot be used with `any_database`.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_name", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .database import *
from .database_backup import *
from .get_acl import *
from .get_database import *
from .get_database_backup import *
from .get_instance import *
from .get_privilege import *
from .instance import *
from .privilege import *
from .read_replica import *
from .serverless_database import *
from .snapshot import *
from .user import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetResult',
    'AwaitableGetResult',
    'get',
    'get_output',
]

@pulumi.output_type
class GetResult:
    """
    A collection of values returned by get.
    """
    def __init__(__self__, bucket=None, content=None, content_base64=None, content_type=None, file=None, hash=None, id=None, key=None, metadata=None, project_id=None, region=None, sse_customer_key=None, storage_class=None, tags=None, visibility=None):
        if bucket and not isinstance(bucket, str):
            raise TypeError("Expected argument 'bucket' to be a str")
        pulumi.set(__self__, "bucket", bucket)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if content_base64 and not isinstance(content_base64, str):
            raise TypeError("Expected argument 'content_base64' to be a str")
        pulumi.set(__self__, "content_base64", content_base64)
        if content_type and not isinstance(content_type, str):
            raise TypeError("Expected argument 'content_type' to be a str")
        pulumi.set(__self__, "content_type", content_type)
        if file and not isinstance(file, str):
            raise TypeError("Expected argument 'file' to be a str")
        pulumi.set(__self__, "file", file)
        if hash and not isinstance(hash, str):
            raise TypeError("Expected argument 'hash' to be a str")
        pulumi.set(__self__, "hash", hash)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if metadata and not isinstance(metadata, dict):
            raise TypeError("Expected argument 'metadata' to be a dict")
        pulumi.set(__self__, "metadata", metadata)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if sse_customer_key and not isinstance(sse_customer_key, str):
            raise TypeError("Expected argument 'sse_customer_key' to be a str")
        pulumi.set(__self__, "sse_customer_key", sse_customer_key)
        if storage_class and not isinstance(storage_class, str):
            raise TypeError("Expected argument 'storage_class' to be a str")
        pulumi.set(__self__, "storage_class", storage_class)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if visibility and not isinstance(visibility, str):
            raise TypeError("Expected argument 'visibility' to be a str")
        pulumi.set(__self__, "visibility", visibility)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> _builtins.str:
        return pulumi.get(self, "bucket")

    @_builtins.property
    @pulumi.getter
    def content(self) -> _builtins.str:
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="contentBase64")
    def content_base64(self) -> _builtins.str:
        return pulumi.get(self, "content_base64")

    @_builtins.property
    @pulumi.getter(name="contentType")
    def content_type(self) -> _builtins.str:
        return pulumi.get(self, "content_type")

    @_builtins.property
    @pulumi.getter
    def file(self) -> _builtins.str:
        return pulumi.get(self, "file")

    @_builtins.property
    @pulumi.getter
    def hash(self) -> _builtins.str:
        return pulumi.get(self, "hash")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def key(self) -> _builtins.str:
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Mapping[str, _builtins.str]:
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="sseCustomerKey")
    def sse_customer_key(self) -> _builtins.str:
        return pulumi.get(self, "sse_customer_key")

    @_builtins.property
    @pulumi.getter(name="storageClass")
    def storage_class(self) -> _builtins.str:
        return pulumi.get(self, "storage_class")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def visibility(self) -> _builtins.str:
        return pulumi.get(self, "visibility")


class AwaitableGetResult(GetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetResult(
            bucket=self.bucket,
            content=self.content,
            content_base64=self.content_base64,
            content_type=self.content_type,
            file=self.file,
            hash=self.hash,
            id=self.id,
            key=self.key,
            metadata=self.metadata,
            project_id=self.project_id,
            region=self.region,
            sse_customer_key=self.sse_customer_key,
            storage_class=self.storage_class,
            tags=self.tags,
            visibility=self.visibility)


def get(bucket: Optional[_builtins.str] = None,
        key: Optional[_builtins.str] = None,
        project_id: Optional[_builtins.str] = None,
        region: Optional[_builtins.str] = None,
        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetResult:
    """
    The `object.Item` data source is used to retrieve information about an Object Storage object.

    Refer to the Object Storage [documentation](https://www.scaleway.com/en/docs/object-storage/how-to/create-a-bucket/) for more information.

    ## Retrieve an Object Storage object

    The following example demonstrates how to retrieve metadata about an object stored in a bucket:

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    main = scaleway.object.Bucket("main", name="bucket.test.com")
    example = scaleway.object.Item("example",
        bucket=main.name,
        key="example.txt",
        content="Hello world!")
    selected = scaleway.object.get_output(bucket=example.bucket,
        key=example.key)
    ```


    :param _builtins.str key: The key (path or filename) of the object within the bucket.
    :param _builtins.str project_id: `project_id`) The ID of the project with which the bucket is associated.
    :param _builtins.str region: `region`) The region in which the bucket exists.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['key'] = key
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:object/get:get', __args__, opts=opts, typ=GetResult).value

    return AwaitableGetResult(
        bucket=pulumi.get(__ret__, 'bucket'),
        content=pulumi.get(__ret__, 'content'),
        content_base64=pulumi.get(__ret__, 'content_base64'),
        content_type=pulumi.get(__ret__, 'content_type'),
        file=pulumi.get(__ret__, 'file'),
        hash=pulumi.get(__ret__, 'hash'),
        id=pulumi.get(__ret__, 'id'),
        key=pulumi.get(__ret__, 'key'),
        metadata=pulumi.get(__ret__, 'metadata'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        sse_customer_key=pulumi.get(__ret__, 'sse_customer_key'),
        storage_class=pulumi.get(__ret__, 'storage_class'),
        tags=pulumi.get(__ret__, 'tags'),
        visibility=pulumi.get(__ret__, 'visibility'))
def get_output(bucket: Optional[pulumi.Input[_builtins.str]] = None,
               key: Optional[pulumi.Input[_builtins.str]] = None,
               project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
               region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetResult]:
    """
    The `object.Item` data source is used to retrieve information about an Object Storage object.

    Refer to the Object Storage [documentation](https://www.scaleway.com/en/docs/object-storage/how-to/create-a-bucket/) for more information.

    ## Retrieve an Object Storage object

    The following example demonstrates how to retrieve metadata about an object stored in a bucket:

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    main = scaleway.object.Bucket("main", name="bucket.test.com")
    example = scaleway.object.Item("example",
        bucket=main.name,
        key="example.txt",
        content="Hello world!")
    selected = scaleway.object.get_output(bucket=example.bucket,
        key=example.key)
    ```


    :param _builtins.str key: The key (path or filename) of the object within the bucket.
    :param _builtins.str project_id: `project_id`) The ID of the project with which the bucket is associated.
    :param _builtins.str region: `region`) The region in which the bucket exists.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['key'] = key
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:object/get:get', __args__, opts=opts, typ=GetResult)
    return __ret__.apply(lambda __response__: GetResult(
        bucket=pulumi.get(__response__, 'bucket'),
        content=pulumi.get(__response__, 'content'),
        content_base64=pulumi.get(__response__, 'content_base64'),
        content_type=pulumi.get(__response__, 'content_type'),
        file=pulumi.get(__response__, 'file'),
        hash=pulumi.get(__response__, 'hash'),
        id=pulumi.get(__response__, 'id'),
        key=pulumi.get(__response__, 'key'),
        metadata=pulumi.get(__response__, 'metadata'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        sse_customer_key=pulumi.get(__response__, 'sse_customer_key'),
        storage_class=pulumi.get(__response__, 'storage_class'),
        tags=pulumi.get(__response__, 'tags'),
        visibility=pulumi.get(__response__, 'visibility')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RunnerArgs', 'Runner']

@pulumi.input_type
class RunnerArgs:
    def __init__(__self__, *,
                 ci_provider: pulumi.Input[_builtins.str],
                 token: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Runner resource.
        :param pulumi.Input[_builtins.str] ci_provider: The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        :param pulumi.Input[_builtins.str] token: The token used to authenticate the runner to run
        :param pulumi.Input[_builtins.str] url: The URL of the runner to run
        :param pulumi.Input[_builtins.str] name: The name of the runner
        :param pulumi.Input[_builtins.str] project_id: The project_id you want to attach the resource to
        :param pulumi.Input[_builtins.str] zone: The zone of the runner
        """
        pulumi.set(__self__, "ci_provider", ci_provider)
        pulumi.set(__self__, "token", token)
        pulumi.set(__self__, "url", url)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="ciProvider")
    def ci_provider(self) -> pulumi.Input[_builtins.str]:
        """
        The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        """
        return pulumi.get(self, "ci_provider")

    @ci_provider.setter
    def ci_provider(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ci_provider", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Input[_builtins.str]:
        """
        The token used to authenticate the runner to run
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL of the runner to run
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the runner
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project_id you want to attach the resource to
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone of the runner
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _RunnerState:
    def __init__(__self__, *,
                 ci_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 error_message: Optional[pulumi.Input[_builtins.str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Runner resources.
        :param pulumi.Input[_builtins.str] ci_provider: The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        :param pulumi.Input[_builtins.str] error_message: The error message if the runner is in error state
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] labels: A list of labels applied to the runner. Only for github provider
        :param pulumi.Input[_builtins.str] name: The name of the runner
        :param pulumi.Input[_builtins.str] project_id: The project_id you want to attach the resource to
        :param pulumi.Input[_builtins.str] status: The status of the runner
        :param pulumi.Input[_builtins.str] token: The token used to authenticate the runner to run
        :param pulumi.Input[_builtins.str] url: The URL of the runner to run
        :param pulumi.Input[_builtins.str] zone: The zone of the runner
        """
        if ci_provider is not None:
            pulumi.set(__self__, "ci_provider", ci_provider)
        if error_message is not None:
            pulumi.set(__self__, "error_message", error_message)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="ciProvider")
    def ci_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        """
        return pulumi.get(self, "ci_provider")

    @ci_provider.setter
    def ci_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ci_provider", value)

    @_builtins.property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The error message if the runner is in error state
        """
        return pulumi.get(self, "error_message")

    @error_message.setter
    def error_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "error_message", value)

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of labels applied to the runner. Only for github provider
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "labels", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the runner
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project_id you want to attach the resource to
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the runner
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The token used to authenticate the runner to run
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the runner to run
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone of the runner
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("scaleway:applesilicon/runner:Runner")
class Runner(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ci_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Apple silicon runners.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.applesilicon.Runner("main",
            name="my-github-runner",
            ci_provider="github",
            url="https://github.com/my-org/my-repo",
            token="my-token")
        ```

        ## Import

        Runner can be imported using the `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:applesilicon/runner:Runner main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] ci_provider: The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        :param pulumi.Input[_builtins.str] name: The name of the runner
        :param pulumi.Input[_builtins.str] project_id: The project_id you want to attach the resource to
        :param pulumi.Input[_builtins.str] token: The token used to authenticate the runner to run
        :param pulumi.Input[_builtins.str] url: The URL of the runner to run
        :param pulumi.Input[_builtins.str] zone: The zone of the runner
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RunnerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Apple silicon runners.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.applesilicon.Runner("main",
            name="my-github-runner",
            ci_provider="github",
            url="https://github.com/my-org/my-repo",
            token="my-token")
        ```

        ## Import

        Runner can be imported using the `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:applesilicon/runner:Runner main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param RunnerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RunnerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ci_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RunnerArgs.__new__(RunnerArgs)

            if ci_provider is None and not opts.urn:
                raise TypeError("Missing required property 'ci_provider'")
            __props__.__dict__["ci_provider"] = ci_provider
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            if token is None and not opts.urn:
                raise TypeError("Missing required property 'token'")
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["zone"] = zone
            __props__.__dict__["error_message"] = None
            __props__.__dict__["labels"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Runner, __self__).__init__(
            'scaleway:applesilicon/runner:Runner',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ci_provider: Optional[pulumi.Input[_builtins.str]] = None,
            error_message: Optional[pulumi.Input[_builtins.str]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'Runner':
        """
        Get an existing Runner resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] ci_provider: The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        :param pulumi.Input[_builtins.str] error_message: The error message if the runner is in error state
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] labels: A list of labels applied to the runner. Only for github provider
        :param pulumi.Input[_builtins.str] name: The name of the runner
        :param pulumi.Input[_builtins.str] project_id: The project_id you want to attach the resource to
        :param pulumi.Input[_builtins.str] status: The status of the runner
        :param pulumi.Input[_builtins.str] token: The token used to authenticate the runner to run
        :param pulumi.Input[_builtins.str] url: The URL of the runner to run
        :param pulumi.Input[_builtins.str] zone: The zone of the runner
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RunnerState.__new__(_RunnerState)

        __props__.__dict__["ci_provider"] = ci_provider
        __props__.__dict__["error_message"] = error_message
        __props__.__dict__["labels"] = labels
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["status"] = status
        __props__.__dict__["token"] = token
        __props__.__dict__["url"] = url
        __props__.__dict__["zone"] = zone
        return Runner(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="ciProvider")
    def ci_provider(self) -> pulumi.Output[_builtins.str]:
        """
        The CI/CD provider for the runner. Must be either 'github' or 'gitlab'
        """
        return pulumi.get(self, "ci_provider")

    @_builtins.property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> pulumi.Output[_builtins.str]:
        """
        The error message if the runner is in error state
        """
        return pulumi.get(self, "error_message")

    @_builtins.property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of labels applied to the runner. Only for github provider
        """
        return pulumi.get(self, "labels")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the runner
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The project_id you want to attach the resource to
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the runner
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[_builtins.str]:
        """
        The token used to authenticate the runner to run
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the runner to run
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The zone of the runner
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetProductsResult',
    'AwaitableGetProductsResult',
    'get_products',
    'get_products_output',
]

@pulumi.output_type
class GetProductsResult:
    """
    A collection of values returned by getProducts.
    """
    def __init__(__self__, id=None, names=None, products=None, region=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if products and not isinstance(products, list):
            raise TypeError("Expected argument 'products' to be a list")
        pulumi.set(__self__, "products", products)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def names(self) -> Sequence[_builtins.str]:
        """
        List of product names for use in scaleway*cockpit*exporter.exported_products.
        """
        return pulumi.get(self, "names")

    @_builtins.property
    @pulumi.getter
    def products(self) -> Sequence['outputs.GetProductsProductResult']:
        """
        List of Cockpit products available for exported*products in scaleway*cockpit_exporter.
        """
        return pulumi.get(self, "products")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        The region you want to attach the resource to
        """
        return pulumi.get(self, "region")


class AwaitableGetProductsResult(GetProductsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProductsResult(
            id=self.id,
            names=self.names,
            products=self.products,
            region=self.region)


def get_products(region: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProductsResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str region: The region you want to attach the resource to
    """
    __args__ = dict()
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:observability/getProducts:getProducts', __args__, opts=opts, typ=GetProductsResult).value

    return AwaitableGetProductsResult(
        id=pulumi.get(__ret__, 'id'),
        names=pulumi.get(__ret__, 'names'),
        products=pulumi.get(__ret__, 'products'),
        region=pulumi.get(__ret__, 'region'))
def get_products_output(region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProductsResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str region: The region you want to attach the resource to
    """
    __args__ = dict()
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:observability/getProducts:getProducts', __args__, opts=opts, typ=GetProductsResult)
    return __ret__.apply(lambda __response__: GetProductsResult(
        id=pulumi.get(__response__, 'id'),
        names=pulumi.get(__response__, 'names'),
        products=pulumi.get(__response__, 'products'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDnsStageResult',
    'AwaitableGetDnsStageResult',
    'get_dns_stage',
    'get_dns_stage_output',
]

@pulumi.output_type
class GetDnsStageResult:
    """
    A collection of values returned by getDnsStage.
    """
    def __init__(__self__, backend_stage_id=None, cache_stage_id=None, created_at=None, default_fqdn=None, dns_stage_id=None, fqdn=None, fqdns=None, id=None, pipeline_id=None, project_id=None, tls_stage_id=None, type=None, updated_at=None):
        if backend_stage_id and not isinstance(backend_stage_id, str):
            raise TypeError("Expected argument 'backend_stage_id' to be a str")
        pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if cache_stage_id and not isinstance(cache_stage_id, str):
            raise TypeError("Expected argument 'cache_stage_id' to be a str")
        pulumi.set(__self__, "cache_stage_id", cache_stage_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if default_fqdn and not isinstance(default_fqdn, str):
            raise TypeError("Expected argument 'default_fqdn' to be a str")
        pulumi.set(__self__, "default_fqdn", default_fqdn)
        if dns_stage_id and not isinstance(dns_stage_id, str):
            raise TypeError("Expected argument 'dns_stage_id' to be a str")
        pulumi.set(__self__, "dns_stage_id", dns_stage_id)
        if fqdn and not isinstance(fqdn, str):
            raise TypeError("Expected argument 'fqdn' to be a str")
        pulumi.set(__self__, "fqdn", fqdn)
        if fqdns and not isinstance(fqdns, list):
            raise TypeError("Expected argument 'fqdns' to be a list")
        pulumi.set(__self__, "fqdns", fqdns)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if pipeline_id and not isinstance(pipeline_id, str):
            raise TypeError("Expected argument 'pipeline_id' to be a str")
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tls_stage_id and not isinstance(tls_stage_id, str):
            raise TypeError("Expected argument 'tls_stage_id' to be a str")
        pulumi.set(__self__, "tls_stage_id", tls_stage_id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> _builtins.str:
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="cacheStageId")
    def cache_stage_id(self) -> _builtins.str:
        return pulumi.get(self, "cache_stage_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="defaultFqdn")
    def default_fqdn(self) -> _builtins.str:
        return pulumi.get(self, "default_fqdn")

    @_builtins.property
    @pulumi.getter(name="dnsStageId")
    def dns_stage_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "dns_stage_id")

    @_builtins.property
    @pulumi.getter
    def fqdn(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "fqdn")

    @_builtins.property
    @pulumi.getter
    def fqdns(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "fqdns")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="tlsStageId")
    def tls_stage_id(self) -> _builtins.str:
        return pulumi.get(self, "tls_stage_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")


class AwaitableGetDnsStageResult(GetDnsStageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDnsStageResult(
            backend_stage_id=self.backend_stage_id,
            cache_stage_id=self.cache_stage_id,
            created_at=self.created_at,
            default_fqdn=self.default_fqdn,
            dns_stage_id=self.dns_stage_id,
            fqdn=self.fqdn,
            fqdns=self.fqdns,
            id=self.id,
            pipeline_id=self.pipeline_id,
            project_id=self.project_id,
            tls_stage_id=self.tls_stage_id,
            type=self.type,
            updated_at=self.updated_at)


def get_dns_stage(dns_stage_id: Optional[_builtins.str] = None,
                  fqdn: Optional[_builtins.str] = None,
                  pipeline_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDnsStageResult:
    """
    Gets information about an Edge Services DNS stage.

    A DNS stage defines the Fully Qualified Domain Names (FQDNs) attached to an Edge Services pipeline and links them to the next processing stage.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services DNS stage by its ID
    by_id = scaleway.edgeservices.get_dns_stage(dns_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services DNS stage by pipeline ID and FQDN
    by_fqdn = scaleway.edgeservices.get_dns_stage(pipeline_id=main["id"],
        fqdn="cdn.example.com")
    ```


    :param _builtins.str dns_stage_id: The ID of the DNS stage. Conflicts with all filter arguments below.
           
           The following filter arguments are supported (cannot be used with `dns_stage_id`):
    :param _builtins.str fqdn: FQDN to filter for (in the format subdomain.example.com).
    :param _builtins.str pipeline_id: The ID of the pipeline.
    """
    __args__ = dict()
    __args__['dnsStageId'] = dns_stage_id
    __args__['fqdn'] = fqdn
    __args__['pipelineId'] = pipeline_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:edgeservices/getDnsStage:getDnsStage', __args__, opts=opts, typ=GetDnsStageResult).value

    return AwaitableGetDnsStageResult(
        backend_stage_id=pulumi.get(__ret__, 'backend_stage_id'),
        cache_stage_id=pulumi.get(__ret__, 'cache_stage_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        default_fqdn=pulumi.get(__ret__, 'default_fqdn'),
        dns_stage_id=pulumi.get(__ret__, 'dns_stage_id'),
        fqdn=pulumi.get(__ret__, 'fqdn'),
        fqdns=pulumi.get(__ret__, 'fqdns'),
        id=pulumi.get(__ret__, 'id'),
        pipeline_id=pulumi.get(__ret__, 'pipeline_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tls_stage_id=pulumi.get(__ret__, 'tls_stage_id'),
        type=pulumi.get(__ret__, 'type'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_dns_stage_output(dns_stage_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         fqdn: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         pipeline_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDnsStageResult]:
    """
    Gets information about an Edge Services DNS stage.

    A DNS stage defines the Fully Qualified Domain Names (FQDNs) attached to an Edge Services pipeline and links them to the next processing stage.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services DNS stage by its ID
    by_id = scaleway.edgeservices.get_dns_stage(dns_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services DNS stage by pipeline ID and FQDN
    by_fqdn = scaleway.edgeservices.get_dns_stage(pipeline_id=main["id"],
        fqdn="cdn.example.com")
    ```


    :param _builtins.str dns_stage_id: The ID of the DNS stage. Conflicts with all filter arguments below.
           
           The following filter arguments are supported (cannot be used with `dns_stage_id`):
    :param _builtins.str fqdn: FQDN to filter for (in the format subdomain.example.com).
    :param _builtins.str pipeline_id: The ID of the pipeline.
    """
    __args__ = dict()
    __args__['dnsStageId'] = dns_stage_id
    __args__['fqdn'] = fqdn
    __args__['pipelineId'] = pipeline_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:edgeservices/getDnsStage:getDnsStage', __args__, opts=opts, typ=GetDnsStageResult)
    return __ret__.apply(lambda __response__: GetDnsStageResult(
        backend_stage_id=pulumi.get(__response__, 'backend_stage_id'),
        cache_stage_id=pulumi.get(__response__, 'cache_stage_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        default_fqdn=pulumi.get(__response__, 'default_fqdn'),
        dns_stage_id=pulumi.get(__response__, 'dns_stage_id'),
        fqdn=pulumi.get(__response__, 'fqdn'),
        fqdns=pulumi.get(__response__, 'fqdns'),
        id=pulumi.get(__response__, 'id'),
        pipeline_id=pulumi.get(__response__, 'pipeline_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tls_stage_id=pulumi.get(__response__, 'tls_stage_id'),
        type=pulumi.get(__response__, 'type'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_sns import *
from .get_sqs import *
from .nats_account import *
from .nats_credentials import *
from .sns import *
from .sns_credentials import *
from .sns_topic import *
from .sns_topic_subscription import *
from .sqs import *
from .sqs_credentials import *
from .sqs_queue import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPublicGatewayDhcpResult',
    'AwaitableGetPublicGatewayDhcpResult',
    'get_public_gateway_dhcp',
    'get_public_gateway_dhcp_output',
]

@pulumi.output_type
class GetPublicGatewayDhcpResult:
    """
    A collection of values returned by getPublicGatewayDhcp.
    """
    def __init__(__self__, address=None, created_at=None, dhcp_id=None, dns_local_name=None, dns_searches=None, dns_servers_overrides=None, enable_dynamic=None, id=None, organization_id=None, pool_high=None, pool_low=None, project_id=None, push_default_route=None, push_dns_server=None, rebind_timer=None, renew_timer=None, subnet=None, updated_at=None, valid_lifetime=None, zone=None):
        if address and not isinstance(address, str):
            raise TypeError("Expected argument 'address' to be a str")
        pulumi.set(__self__, "address", address)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if dhcp_id and not isinstance(dhcp_id, str):
            raise TypeError("Expected argument 'dhcp_id' to be a str")
        pulumi.set(__self__, "dhcp_id", dhcp_id)
        if dns_local_name and not isinstance(dns_local_name, str):
            raise TypeError("Expected argument 'dns_local_name' to be a str")
        pulumi.set(__self__, "dns_local_name", dns_local_name)
        if dns_searches and not isinstance(dns_searches, list):
            raise TypeError("Expected argument 'dns_searches' to be a list")
        pulumi.set(__self__, "dns_searches", dns_searches)
        if dns_servers_overrides and not isinstance(dns_servers_overrides, list):
            raise TypeError("Expected argument 'dns_servers_overrides' to be a list")
        pulumi.set(__self__, "dns_servers_overrides", dns_servers_overrides)
        if enable_dynamic and not isinstance(enable_dynamic, bool):
            raise TypeError("Expected argument 'enable_dynamic' to be a bool")
        pulumi.set(__self__, "enable_dynamic", enable_dynamic)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if pool_high and not isinstance(pool_high, str):
            raise TypeError("Expected argument 'pool_high' to be a str")
        pulumi.set(__self__, "pool_high", pool_high)
        if pool_low and not isinstance(pool_low, str):
            raise TypeError("Expected argument 'pool_low' to be a str")
        pulumi.set(__self__, "pool_low", pool_low)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if push_default_route and not isinstance(push_default_route, bool):
            raise TypeError("Expected argument 'push_default_route' to be a bool")
        pulumi.set(__self__, "push_default_route", push_default_route)
        if push_dns_server and not isinstance(push_dns_server, bool):
            raise TypeError("Expected argument 'push_dns_server' to be a bool")
        pulumi.set(__self__, "push_dns_server", push_dns_server)
        if rebind_timer and not isinstance(rebind_timer, int):
            raise TypeError("Expected argument 'rebind_timer' to be a int")
        pulumi.set(__self__, "rebind_timer", rebind_timer)
        if renew_timer and not isinstance(renew_timer, int):
            raise TypeError("Expected argument 'renew_timer' to be a int")
        pulumi.set(__self__, "renew_timer", renew_timer)
        if subnet and not isinstance(subnet, str):
            raise TypeError("Expected argument 'subnet' to be a str")
        pulumi.set(__self__, "subnet", subnet)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if valid_lifetime and not isinstance(valid_lifetime, int):
            raise TypeError("Expected argument 'valid_lifetime' to be a int")
        pulumi.set(__self__, "valid_lifetime", valid_lifetime)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def address(self) -> _builtins.str:
        return pulumi.get(self, "address")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="dhcpId")
    def dhcp_id(self) -> _builtins.str:
        return pulumi.get(self, "dhcp_id")

    @_builtins.property
    @pulumi.getter(name="dnsLocalName")
    def dns_local_name(self) -> _builtins.str:
        return pulumi.get(self, "dns_local_name")

    @_builtins.property
    @pulumi.getter(name="dnsSearches")
    def dns_searches(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "dns_searches")

    @_builtins.property
    @pulumi.getter(name="dnsServersOverrides")
    def dns_servers_overrides(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "dns_servers_overrides")

    @_builtins.property
    @pulumi.getter(name="enableDynamic")
    def enable_dynamic(self) -> _builtins.bool:
        return pulumi.get(self, "enable_dynamic")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="poolHigh")
    def pool_high(self) -> _builtins.str:
        return pulumi.get(self, "pool_high")

    @_builtins.property
    @pulumi.getter(name="poolLow")
    def pool_low(self) -> _builtins.str:
        return pulumi.get(self, "pool_low")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="pushDefaultRoute")
    def push_default_route(self) -> _builtins.bool:
        return pulumi.get(self, "push_default_route")

    @_builtins.property
    @pulumi.getter(name="pushDnsServer")
    def push_dns_server(self) -> _builtins.bool:
        return pulumi.get(self, "push_dns_server")

    @_builtins.property
    @pulumi.getter(name="rebindTimer")
    def rebind_timer(self) -> _builtins.int:
        return pulumi.get(self, "rebind_timer")

    @_builtins.property
    @pulumi.getter(name="renewTimer")
    def renew_timer(self) -> _builtins.int:
        return pulumi.get(self, "renew_timer")

    @_builtins.property
    @pulumi.getter
    def subnet(self) -> _builtins.str:
        return pulumi.get(self, "subnet")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="validLifetime")
    def valid_lifetime(self) -> _builtins.int:
        return pulumi.get(self, "valid_lifetime")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> _builtins.str:
        return pulumi.get(self, "zone")


class AwaitableGetPublicGatewayDhcpResult(GetPublicGatewayDhcpResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPublicGatewayDhcpResult(
            address=self.address,
            created_at=self.created_at,
            dhcp_id=self.dhcp_id,
            dns_local_name=self.dns_local_name,
            dns_searches=self.dns_searches,
            dns_servers_overrides=self.dns_servers_overrides,
            enable_dynamic=self.enable_dynamic,
            id=self.id,
            organization_id=self.organization_id,
            pool_high=self.pool_high,
            pool_low=self.pool_low,
            project_id=self.project_id,
            push_default_route=self.push_default_route,
            push_dns_server=self.push_dns_server,
            rebind_timer=self.rebind_timer,
            renew_timer=self.renew_timer,
            subnet=self.subnet,
            updated_at=self.updated_at,
            valid_lifetime=self.valid_lifetime,
            zone=self.zone)


def get_public_gateway_dhcp(dhcp_id: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPublicGatewayDhcpResult:
    """
    > **Important:**  The data source `network.PublicGatewayDhcp` has been deprecated and will no longer be supported.
    In 2023, DHCP functionality was moved from Public Gateways to Private Networks, DHCP resources are now no longer needed.
    For more information, please refer to the dedicated guide.

    Gets information about a Public Gateway DHCP configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    main = scaleway.network.PublicGatewayDhcp("main", subnet="192.168.0.0/24")
    dhcp_by_id = scaleway.network.get_public_gateway_dhcp_output(dhcp_id=main.id)
    ```
    """
    __args__ = dict()
    __args__['dhcpId'] = dhcp_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:network/getPublicGatewayDhcp:getPublicGatewayDhcp', __args__, opts=opts, typ=GetPublicGatewayDhcpResult).value

    return AwaitableGetPublicGatewayDhcpResult(
        address=pulumi.get(__ret__, 'address'),
        created_at=pulumi.get(__ret__, 'created_at'),
        dhcp_id=pulumi.get(__ret__, 'dhcp_id'),
        dns_local_name=pulumi.get(__ret__, 'dns_local_name'),
        dns_searches=pulumi.get(__ret__, 'dns_searches'),
        dns_servers_overrides=pulumi.get(__ret__, 'dns_servers_overrides'),
        enable_dynamic=pulumi.get(__ret__, 'enable_dynamic'),
        id=pulumi.get(__ret__, 'id'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        pool_high=pulumi.get(__ret__, 'pool_high'),
        pool_low=pulumi.get(__ret__, 'pool_low'),
        project_id=pulumi.get(__ret__, 'project_id'),
        push_default_route=pulumi.get(__ret__, 'push_default_route'),
        push_dns_server=pulumi.get(__ret__, 'push_dns_server'),
        rebind_timer=pulumi.get(__ret__, 'rebind_timer'),
        renew_timer=pulumi.get(__ret__, 'renew_timer'),
        subnet=pulumi.get(__ret__, 'subnet'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        valid_lifetime=pulumi.get(__ret__, 'valid_lifetime'),
        zone=pulumi.get(__ret__, 'zone'))
def get_public_gateway_dhcp_output(dhcp_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPublicGatewayDhcpResult]:
    """
    > **Important:**  The data source `network.PublicGatewayDhcp` has been deprecated and will no longer be supported.
    In 2023, DHCP functionality was moved from Public Gateways to Private Networks, DHCP resources are now no longer needed.
    For more information, please refer to the dedicated guide.

    Gets information about a Public Gateway DHCP configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    main = scaleway.network.PublicGatewayDhcp("main", subnet="192.168.0.0/24")
    dhcp_by_id = scaleway.network.get_public_gateway_dhcp_output(dhcp_id=main.id)
    ```
    """
    __args__ = dict()
    __args__['dhcpId'] = dhcp_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:network/getPublicGatewayDhcp:getPublicGatewayDhcp', __args__, opts=opts, typ=GetPublicGatewayDhcpResult)
    return __ret__.apply(lambda __response__: GetPublicGatewayDhcpResult(
        address=pulumi.get(__response__, 'address'),
        created_at=pulumi.get(__response__, 'created_at'),
        dhcp_id=pulumi.get(__response__, 'dhcp_id'),
        dns_local_name=pulumi.get(__response__, 'dns_local_name'),
        dns_searches=pulumi.get(__response__, 'dns_searches'),
        dns_servers_overrides=pulumi.get(__response__, 'dns_servers_overrides'),
        enable_dynamic=pulumi.get(__response__, 'enable_dynamic'),
        id=pulumi.get(__response__, 'id'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        pool_high=pulumi.get(__response__, 'pool_high'),
        pool_low=pulumi.get(__response__, 'pool_low'),
        project_id=pulumi.get(__response__, 'project_id'),
        push_default_route=pulumi.get(__response__, 'push_default_route'),
        push_dns_server=pulumi.get(__response__, 'push_dns_server'),
        rebind_timer=pulumi.get(__response__, 'rebind_timer'),
        renew_timer=pulumi.get(__response__, 'renew_timer'),
        subnet=pulumi.get(__response__, 'subnet'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        valid_lifetime=pulumi.get(__response__, 'valid_lifetime'),
        zone=pulumi.get(__response__, 'zone')))
